pub struct TimeoutFlags(/* private fields */);Implementations
Sourceimpl TimeoutFlags
Options for Timeout.
impl TimeoutFlags
Options for Timeout.
The default behavior is to treat the timespec as a relative time interval. flags may
contain TimeoutFlags::ABS to indicate the timespec represents an absolute
time. When an absolute time is being specified, the kernel will use its monotonic clock
unless one of the following flags is set (they may not both be set):
TimeoutFlags::BOOTTIME or TimeoutFlags::REALTIME.
The default behavior when the timeout expires is to sever dependent links, as a failed
request normally would. To keep the links untouched include TimeoutFlags::ETIME_SUCCESS.
CQE will still contain -libc::ETIME in the res field